@@ -1,6 +1,7 @@
 # Copyright 2016-2018 Dirk Thomas
 # Licensed under the Apache License, Version 2.0
 
+from collections import defaultdict
 import os
 from pathlib import Path
 
@@ -49,7 +50,8 @@ def test_get_dependencies():
     assert "'self'" in str(e.value)
 
 
-def test_get_recursive_dependencies():
+@pytest.fixture
+def recursive_dependencies():
     d = PackageDescriptor('/some/path')
     d.name = 'A'
     d.dependencies['build'].add('B')
@@ -70,6 +72,7 @@ def test_get_recursive_dependencies():
     d3.dependencies['build'].add('h')
     d3.dependencies['test'].add('G')
     d3.dependencies['test'].add('I')
+    d3.dependencies['test'].add('J')
 
     d4 = PackageDescriptor('/more/path')
     d4.name = 'G'
@@ -80,10 +83,35 @@ def test_get_recursive_dependencies():
     # circular dependencies should be ignored
     d5.dependencies['run'].add('A')
 
-    rec_deps = d.get_recursive_dependencies(
-        {d, d1, d2, d3, d4, d5},
+    d6 = PackageDescriptor('/paths/galore')
+    d6.name = 'J'
+
+    return d, {d, d1, d2, d3, d4, d5, d6}
+
+
+def test_get_recursive_dependencies(recursive_dependencies):
+    desc, all_descs = recursive_dependencies
+    rec_deps = desc.get_recursive_dependencies(
+        all_descs,
         direct_categories=('build', 'run'),
         recursive_categories=('run', 'test'))
+    assert rec_deps == {
+        # direct dependencies
+        'B',
+        # recursive dependencies
+        'F', 'G', 'I', 'J',
+    }
+
+
+def test_get_recursive_dependencies_map(recursive_dependencies):
+    recursive_categories = defaultdict(lambda: ('run', 'test'))
+    recursive_categories['run'] = ('run',)
+
+    desc, all_descs = recursive_dependencies
+    rec_deps = desc.get_recursive_dependencies(
+        all_descs,
+        direct_categories=('build', 'run'),
+        recursive_categories=recursive_categories)
     assert rec_deps == {
         # direct dependencies
         'B',
